@@ -1,6 +1,6 @@
 # Run sql files via django#
 # www.heliosfoundation.org
-import sys, os, csv, re
+import os, csv, re
 from datetime import datetime
 import codecs
 import chardet
@@ -8,21 +8,20 @@ import chardet
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.management.base import LabelCommand, BaseCommand
 from optparse import make_option
-from django.db import connection, transaction
-from django.conf import settings
 from django.db import models
 
-from csvimport import models
 # Note if mappings are manually specified they are of the following form ...
 # MAPPINGS = "column1=shared_code,column2=org(Organisation|name),column3=description"
-statements = re.compile(r";[ \t]*$", re.M)
+# statements = re.compile(r";[ \t]*$", re.M)
 
-def save_csvimport(props={}, instance=None):
+def save_csvimport(props=None, instance=None):
     """ To avoid circular imports do saves here """
     if not instance:
-        csvimport = models.CSVImport()
-    for key in props.keys():
-        csvimport.__setattr__(key, value)
+        from csvimport.models import CSVImport
+        csvimport = CSVImport()
+    if props:
+        for key, value in props.items():
+            csvimport.__setattr__(key, value)
     csvimport.save()
     return csvimport.id
 
@@ -43,16 +42,32 @@ class Command(LabelCommand):
                    )
     help = "Imports a CSV file to a model"
 
+
+    def __init__(self):
+        """ Set default attributes data types """
+        super(Command, self).__init__()
+        self.props = {}
+        self.debug = False
+        self.errors = []
+        self.loglist = []
+        self.mappings = []
+        self.defaults = []
+        self.app_label = ''
+        self.model = ''
+        self.file_name = ''
+        self.nameindexes = False
+        self.deduplicate = True
+        self.csvfile = []
+
     def handle_label(self, label, **options):
         """ Handle the circular reference by passing the nested
             save_csvimport function 
         """
         filename = label 
-        mappings = options.get('mappings', []) #MAPPINGS)
+        mappings = options.get('mappings', []) 
         modelname = options.get('model', 'Item')
-        show_traceback = options.get('traceback', True)
+        # show_traceback = options.get('traceback', True)
         self.setup(mappings, modelname, filename)
-        self.props = {}
         errors = self.run()
         if self.props:
             save_csvimport(self.props)
@@ -62,9 +77,6 @@ class Command(LabelCommand):
     def setup(self, mappings, modelname, csvfile='', defaults='',
               uploaded=None, nameindexes=False, deduplicate=True):
         """ Setup up the attributes for running the import """
-        self.debug = False
-        self.errors = []
-        self.loglist = []
         self.defaults = self.__mappings(defaults)
         if modelname.find('.') > -1:
             app_label, model = modelname.split('.')
@@ -72,8 +84,6 @@ class Command(LabelCommand):
         self.model = models.get_model(app_label, model)
         if mappings:
             self.mappings = self.__mappings(mappings)
-        else:
-            self.mappings = []
         self.nameindexes = bool(nameindexes) 
         self.file_name = csvfile
         self.deduplicate = deduplicate
@@ -117,7 +127,9 @@ class Command(LabelCommand):
         else:
             csvimportid = 0
         mapping = []
-        if not self.mappings:
+        if self.mappings:
+             self.loglist.append('Using manually entered mapping list') 
+        else:
             fieldmap = {}
             for field in self.model._meta.fields:
                 fieldmap[field.name] = field
@@ -128,7 +140,15 @@ class Command(LabelCommand):
                         key = self.check_fkey(key, field)
                         mapping.append('column%s=%s' % (i+1, key))
             mappingstr = ','.join(mapping)
-            self.mappings = self.__mappings(mappingstr)            
+            if mapping:
+                self.loglist.append('Using mapping from first row of CSV file') 
+                self.mappings = self.__mappings(mappingstr)            
+        if not self.mappings:
+            self.loglist.append('''No fields in the CSV file match %s.%s\n
+                                   - you must add a header field name row 
+                                   to the CSV file or supply a mapping list''' % 
+                                (self.model._meta.app_label, self.model.__name__))
+            return self.loglist
         for row in self.csvfile[1:]:
             counter += 1
             model_instance = self.model()
@@ -145,7 +165,8 @@ class Command(LabelCommand):
                     row[column] = self.insert_fkey(foreignkey, row[column])
 
                 if self.debug:
-                    self.loglist.append('%s.%s = "%s"' % (self.model, field, row[column]))
+                    self.loglist.append('%s.%s = "%s"' % (self.model.__name__, 
+                                                          field, row[column]))
                 #if type(row[column]) == type(''):
                 #    row[column] = unicode(row[column])
                 try:
@@ -176,7 +197,7 @@ class Command(LabelCommand):
                     matchdict[field + '__exact'] = getattr(model_instance, 
                                                            field, None)
                 try:
-                    exists = self.model.objects.get(**matchdict)
+                    self.model.objects.get(**matchdict)
                     continue
                 except ObjectDoesNotExist:
                     pass
@@ -200,16 +221,16 @@ class Command(LabelCommand):
         """
         fk_key, fk_field = foreignkey
         if fk_key and fk_field:
-            fk = models.get_model(self.app_label, fk_key)
-            matches = fk.objects.filter(**{fk_field+'__exact': 
-                                           rowcol})
+            fk_model = models.get_model(self.app_label, fk_key)
+            matches = fk_model.objects.filter(**{fk_field+'__exact': 
+                                                 rowcol})
 
             if not matches:
-                key = fk()
+                key = fk_model()
                 key.__setattr__(fk_field, rowcol)
                 key.save()
 
-            rowcol = fk.objects.filter(**{fk_field+'__exact': rowcol})[0]
+            rowcol = fk_model.objects.filter(**{fk_field+'__exact': rowcol})[0]
         return rowcol
         
     def error(self, message, type=1):
@@ -234,8 +255,8 @@ class Command(LabelCommand):
     
     def __csvfile(self, datafile):
         """ Detect file encoding and open appropriately """
-        fh = open(datafile)
-        diagnose = chardet.detect(fh.read())
+        filehandle = open(datafile)
+        diagnose = chardet.detect(filehandle.read())
         charset = diagnose['encoding']
         try:
             csvfile = codecs.open(datafile, 'r', charset)
@@ -260,21 +281,13 @@ class Command(LabelCommand):
         for line in csv_data:
             yield line.encode(charset)
     
-    def __model(self, model='Item'):
-        # In order to properly import the models, and figure out what settings 
-        # to use, we need to figure out the application and project names.
-        try:
-            from iisharing import models
-        except ImportError:
-            self.error('Specified directory does not exist')
-        else:
-            return models.Item
-    
     def __mappings(self, mappings):
         """
         Parse the mappings, and return a list of them.
         """
-        
+        if not mappings:
+            return []
+
         def parse_mapping(args):
             """
             Parse the custom mapping syntax (column1=field1(ForeignKey|field),
@@ -289,10 +302,10 @@ class Command(LabelCommand):
             
             mappings = list(mappings)
             for mapping in mappings:
-                m = mappings.index(mapping)
-                mappings[m] = list(mappings[m])
-                mappings[m][2] = parse_foreignkey(mapping[2])
-                mappings[m] = tuple(mappings[m])
+                mapp = mappings.index(mapping)
+                mappings[mapp] = list(mappings[mapp])
+                mappings[mapp][2] = parse_foreignkey(mapping[2])
+                mappings[mapp] = tuple(mappings[mapp])
             mappings = list(mappings)
             
             return mappings
@@ -315,7 +328,7 @@ class Command(LabelCommand):
                 return (found.group(1), found.group(2))
             else:
                 return None
-                    
+
         mappings = mappings.replace(',', ' ')
         mappings = mappings.replace('column', '')
         return parse_mapping(mappings)
